@@ -5,7 +5,8 @@ from myst.client import Client, get_client, set_client
 from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
-from myst.models.timing import AbsoluteTiming, RelativeTiming
+from myst.models.timing import AbsoluteTiming, CronTiming, RelativeTiming
+from myst.resources.backtest import Backtest, BacktestJob
 from myst.resources.input import Input
 from myst.resources.layer import Layer
 from myst.resources.model import Model
@@ -27,6 +28,8 @@ __all__ = [
     "Client",
     "get_client",
     "set_client",
+    "Backtest",
+    "CronTiming",
     "Input",
     "Layer",
     "Model",
