@@ -2,7 +2,8 @@ from myst.connectors.model_connectors.elastic_net import ElasticNet
 from myst.connectors.model_connectors.extra_trees_regression import ExtraTreesRegression
 from myst.connectors.model_connectors.lightgbm import LightGBM
 from myst.connectors.model_connectors.linear_regression import LinearRegression
+from myst.connectors.model_connectors.mlp_regression import  MLPRegression
 from myst.connectors.model_connectors.random_forest_regression import RandomForestRegression
 from myst.connectors.model_connectors.xgboost import XGBoost
 
-__all__ = ["ElasticNet", "ExtraTreesRegression", "LightGBM", "LinearRegression", "RandomForestRegression", "XGBoost"]
+__all__ = ["ElasticNet", "ExtraTreesRegression", "LightGBM", "LinearRegression", "MLPRegression", "RandomForestRegression", "XGBoost"]
