@@ -27,7 +27,7 @@ class CronTiming(Timing):
     time_zone: Optional[str] = "UTC"
 
 
-ScheduleTiming = Union[AbsoluteTiming, RelativeTiming]
+ScheduleTiming = Union[AbsoluteTiming, CronTiming, RelativeTiming]
 AbsoluteOrRelativeTiming = Union[AbsoluteTiming, RelativeTiming]
 AbsoluteOrCronTiming = Union[AbsoluteTiming, CronTiming]
 TimeRangeBoundary = Union[Time, TimeDelta, AbsoluteOrRelativeTiming]
@@ -91,7 +91,7 @@ def from_schedule_specifier(timing: Union[Time, TimeDelta, ScheduleTiming]) -> S
         return AbsoluteTiming(time=timing)
     elif isinstance(timing, TimeDelta):
         return RelativeTiming(frequency=timing)
-    elif isinstance(timing, (AbsoluteTiming, RelativeTiming)):
+    elif isinstance(timing, (AbsoluteTiming, RelativeTiming, CronTiming)):
         return timing
     else:
         raise TypeError("Argument must be of type `Time`, `TimeDelta, or `ScheduleTiming`.")
