@@ -4,10 +4,9 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.absolute_timing_create import AbsoluteTimingCreate
-from ..models.cron_timing_create import CronTimingCreate
-from ..models.relative_timing_create import RelativeTimingCreate
+from myst.openapi.models.absolute_timing_create import AbsoluteTimingCreate
+from myst.openapi.models.cron_timing_create import CronTimingCreate
+from myst.openapi.models.relative_timing_create import RelativeTimingCreate
 
 
 class ModelFitPolicyUpdate(base_model.BaseModel):
