@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Dict, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -18,5 +18,6 @@ class ModelRunResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     as_of_time: str
+    inputs: Dict[str, Optional[List[TimeDataset]]]
     outputs: List[TimeDataset]
     update_time: Optional[str] = None
