@@ -1,5 +1,5 @@
 import time
-from typing import Optional
+from typing import List, Optional
 from uuid import UUID
 
 from myst.adapters.timing import to_timing_create
@@ -7,7 +7,7 @@ from myst.client import get_client
 from myst.core.time.time import Time
 from myst.models.timing import AbsoluteOrCronTiming, CronTiming, TimeRangeBoundary, from_time_range_boundary
 from myst.models.types import UUIDOrStr, to_uuid
-from myst.openapi.api.projects.backtests import create_backtest, get_backtest, run_backtest
+from myst.openapi.api.projects.backtests import create_backtest, get_backtest, list_backtests, run_backtest
 from myst.openapi.models.backtest_create import BacktestCreate
 from myst.openapi.models.job_state import JobState
 from myst.resources.backtest_job import BacktestJob
@@ -32,6 +32,13 @@ class Backtest(Resource):
     predict_end_timing: TimeRangeBoundary
     predict_reference_timing: CronTiming
 
+    @classmethod
+    def list(self, project: Project) -> List["Backtest"]:
+        """Lists all backtests associated with this project."""
+        backtests = list_backtests.request_sync(client=get_client(), project_uuid=str(project.uuid))
+
+        return [Backtest.parse_obj(backtest) for backtest in backtests.data]
+
     @classmethod
     def create(
         cls,
