@@ -1,6 +1,6 @@
 from uuid import UUID
 
-from myst.models.timing import AbsoluteOrRelativeTiming
+from myst.models.timing import AbsoluteOrRelativeTiming, ScheduleTiming
 from myst.resources.resource import Resource
 
 
@@ -17,7 +17,7 @@ class Policy(Resource):
     """
 
     creator: UUID
-    schedule_timing: AbsoluteOrRelativeTiming
+    schedule_timing: ScheduleTiming
     active: bool
     node: UUID
     start_timing: AbsoluteOrRelativeTiming
