@@ -9,8 +9,10 @@ from myst.core.time.time_delta import TimeDelta
 from myst.models.enums import DeployStatus, OrgSharingRole
 from myst.models.types import AxisLabels, CoordinateLabels, Shape, UUIDOrStr, to_uuid
 from myst.openapi.api.projects import create_project, get_project, list_projects
+from myst.openapi.api.projects.deployments import create_project_deployment
 from myst.openapi.api.projects.edges import list_project_edges
 from myst.openapi.api.projects.nodes import list_project_nodes
+from myst.openapi.models.deployment_create import DeploymentCreate
 from myst.openapi.models.input_get import InputGet
 from myst.openapi.models.layer_get import LayerGet
 from myst.openapi.models.model_get import ModelGet
@@ -19,6 +21,7 @@ from myst.openapi.models.org_sharing_role import OrgSharingRole as OAIOrgSharing
 from myst.openapi.models.project_create import ProjectCreate
 from myst.openapi.models.source_get import SourceGet
 from myst.openapi.models.time_series_get import TimeSeriesGet
+from myst.resources.deployment import Deployment
 from myst.resources.edge import Edge
 from myst.resources.input import Input
 from myst.resources.layer import Layer
@@ -228,3 +231,21 @@ class Project(ShareableResource):
             the newly created time series
         """
         return recipe.create(project=self, title=title, description=description)
+
+    def deploy(self, title: str) -> Deployment:
+        """Deploys the current project.
+
+        Args:
+            title: the title for the deployment
+
+        Returns:
+            the newly created deployment
+        """
+        deployment = create_project_deployment.request_sync(
+            client=get_client(),
+            project_uuid=str(self.uuid),
+            json_body=DeploymentCreate(object="Deployment", title=title),
+        )
+        deployment_dict = deployment.dict()
+        deployment_dict["project"] = self.uuid
+        return Deployment.parse_obj(deployment_dict)
